==> libnl-doc-3.2.27.tar.gz: libnl-doc-3.2.27/api/navtreedata.js <==
var NAVTREE =
[
  [ "libnl", "index.html", [
    [ "Introduction", "index.html#main_intro", null ],
    [ "Table of Contents", "index.html#main_toc", null ],
    [ "GIT Trees", "index.html#main_trees", [
      [ "Development Tree", "index.html#tree_dev", null ]
    ] ],
    [ "Website", "index.html#main_website", null ],
    [ "Mailinglist", "index.html#main_mailinglist", null ],
    [ "Disabling Auto-ACK", "auto_ack_warning.html", null ],
    [ "Pointer Lifetime", "pointer_lifetime_warning.html", null ],
    [ "Private Structure", "private_struct.html", null ],
    [ "Read-Only Attribute", "read_only_attribute.html", null ],
    [ "Low Level API", "low_level_api.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", null, [
      [ "Data Structures", "annotated.html", "annotated" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__cb.html#gga3f60f4515ada826d2bf16395ee722363a1424b30f447e2fabc6e0e65d05c596dc",
"group__ipvlan.html#gaa1f25e0be814974d6d9b60a1558e365a",
"group__object.html#ga5c483621e839bb4d5a23e77623841364",
"group__sit.html#ga71c04f282884a7824bf7fca3cba783fb",
"structnl__hash__table.html#a141a89824ec26109bcbcce0fe43b4b1f"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> libnl-doc-3.3.0.tar.gz: libnl-doc-3.3.0/api/navtreedata.js <==
var NAVTREE =
[
  [ "libnl", "index.html", [
    [ "Introduction", "index.html#main_intro", null ],
    [ "Table of Contents", "index.html#main_toc", null ],
    [ "GIT Trees", "index.html#main_trees", [
      [ "Development Tree", "index.html#tree_dev", null ]
    ] ],
    [ "Website", "index.html#main_website", null ],
    [ "Mailinglist", "index.html#main_mailinglist", null ],
    [ "Disabling Auto-ACK", "auto_ack_warning.html", null ],
    [ "Pointer Lifetime", "pointer_lifetime_warning.html", null ],
    [ "Private Structure", "private_struct.html", null ],
    [ "Read-Only Attribute", "read_only_attribute.html", null ],
    [ "Low Level API", "low_level_api.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__cb.html#gga0c50cb29c507b3d7e8bc7d76c74675f8abce22d25ef3e2fed30f22f8bc27fc8f0",
"group__ipip.html#gae7cf50f5cb7e52c359f3a568d54ff1ed",
"group__neigh.html#gadfffa6dbcf76d360f53d20eb9aae6451",
"group__rule.html#gac1525a0fa9ffdd715eeb3568f0384f47",
"group__vxlan.html#gaae4e1648fbfd0ab7aba0b5480242265d"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
